@@ -18,7 +18,7 @@
 #error "VDR-1.6.0 API version or greater is required!"
 #endif
 
-static const char VERSION[]       = "1.6.3";
+static const char VERSION[]       = "1.6.7";
 static const char DESCRIPTION[]   = trNOOP("DVB Signal Information Monitor (OSD)");
 static const char MAINMENUENTRY[] = trNOOP("Signal Information");
 
@@ -108,14 +108,12 @@ bool cPluginFemon::SetupParse(const char *Name, const char *Value)
 {
   // Parse your own setup parameters and store their values.
   if      (!strcasecmp(Name, "HideMenu"))       femonConfig.hidemenu       = atoi(Value);
-  else if (!strcasecmp(Name, "UseSingleArea"))  femonConfig.usesinglearea  = atoi(Value);
   else if (!strcasecmp(Name, "DisplayMode"))    femonConfig.displaymode    = atoi(Value);
   else if (!strcasecmp(Name, "Position"))       femonConfig.position       = atoi(Value);
   else if (!strcasecmp(Name, "OSDHeight"))      femonConfig.osdheight      = atoi(Value);
   else if (!strcasecmp(Name, "OSDOffset"))      femonConfig.osdoffset      = atoi(Value);
   else if (!strcasecmp(Name, "Skin"))           femonConfig.skin           = atoi(Value);
   else if (!strcasecmp(Name, "Theme"))          femonConfig.theme          = atoi(Value);
-  else if (!strcasecmp(Name, "ShowCASystem"))   femonConfig.showcasystem   = atoi(Value);
   else if (!strcasecmp(Name, "RedLimit"))       femonConfig.redlimit       = atoi(Value);
   else if (!strcasecmp(Name, "GreenLimit"))     femonConfig.greenlimit     = atoi(Value);
   else if (!strcasecmp(Name, "UpdateInterval")) femonConfig.updateinterval = atoi(Value);
@@ -311,9 +309,6 @@ void cMenuFemonSetup::Setup(void)
   Add(new cMenuEditBoolItem(tr("Hide main menu entry"), &data.hidemenu));
   help.Append(tr("Define whether the main menu entry is hidden."));
 
-  Add(new cMenuEditBoolItem(tr("Use single area (8bpp)"), &data.usesinglearea));
-  help.Append(tr("Define whether a single 8bpp OSD area is preferred.\n\nRequired by Truetype fonts and anti-aliasing."));
-
   Add(new cMenuEditStraItem(tr("Default display mode"), &data.displaymode, eFemonModeMaxNumber, dispmodes));
   help.Append(tr("Define the default display mode at startup."));
 
@@ -332,9 +327,6 @@ void cMenuFemonSetup::Setup(void)
   Add(new cMenuEditIntItem(tr("Horizontal offset"), &data.osdoffset, -50, 50));
   help.Append(tr("Define the horizontal offset of OSD."));
 
-  Add(new cMenuEditBoolItem(tr("Show CA system"), &data.showcasystem));
-  help.Append(tr("Define whether the CA system is shown as text."));
-
   Add(new cMenuEditIntItem(tr("Red limit [%]"), &data.redlimit, 1, 50));
   help.Append(tr("Define a limit for red bar, which is used to indicate a bad signal."));
 
@@ -372,14 +364,12 @@ void cMenuFemonSetup::Store(void)
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
   femonConfig = data;
   SetupStore("HideMenu",       femonConfig.hidemenu);
-  SetupStore("UseSingleArea",  femonConfig.usesinglearea);
   SetupStore("DisplayMode",    femonConfig.displaymode);
   SetupStore("Skin",           femonConfig.skin);
   SetupStore("Theme",          femonConfig.theme);
   SetupStore("Position",       femonConfig.position);
   SetupStore("OSDHeight",      femonConfig.osdheight);
   SetupStore("OSDOffset",      femonConfig.osdoffset);
-  SetupStore("ShowCASystem",   femonConfig.showcasystem);
   SetupStore("RedLimit",       femonConfig.redlimit);
   SetupStore("GreenLimit",     femonConfig.greenlimit);
   SetupStore("UpdateInterval", femonConfig.updateinterval);
