@@ -13,7 +13,6 @@ cFemonConfig femonConfig;
 cFemonConfig::cFemonConfig(void)
 {
   hidemenu       = 0;
-  usesinglearea  = 0;
   displaymode    = 0;
   skin           = 0;
   theme          = 0;
@@ -23,12 +22,7 @@ cFemonConfig::cFemonConfig(void)
   updateinterval = 5;
   analyzestream  = 1;
   calcinterval   = 20;
-  showcasystem   = 0;
-#ifdef NTSC
-  osdheight      = 420;
-#else
   osdheight      = 480;
-#endif
   osdoffset      = 0;
   usesvdrp       = 0;
   svdrpport      = 2001;
