@@ -24,7 +24,6 @@ struct cFemonConfig
 public:
   cFemonConfig(void);
   int hidemenu;
-  int usesinglearea;
   int displaymode;
   int skin;
   int theme;
@@ -34,7 +33,6 @@ public:
   int updateinterval;
   int analyzestream;
   int calcinterval;
-  int showcasystem;
   int osdheight;
   int osdoffset;
   int usesvdrp;
