@@ -21,8 +21,8 @@
 #define OSDINFOHEIGHT             (OSDROWHEIGHT * 13)     // in pixels (13 rows)
 #define OSDSTATUSHEIGHT           (OSDROWHEIGHT * 6)      // in pixels (6 rows)
 #define OSDSPACING                5
-#define OSDCORNERING              10
-#define IS_OSDCORNERING           (femonConfig.skin == eFemonSkinElchi)
+#define OSDROUNDING               10
+#define IS_OSDROUNDING            (femonConfig.skin == eFemonSkinElchi)
 
 #define OSDINFOWIN_Y(offset)      (femonConfig.position ? (OSDHEIGHT - OSDINFOHEIGHT + offset) : offset)
 #define OSDINFOWIN_X(col)         ((col == 4) ? 455 : (col == 3) ? 305 : (col == 2) ? 155 : 15)
@@ -36,11 +36,11 @@
            x -= bm->Width() + spacing; \
            y = (OSDROWHEIGHT - bm->Height()) / 2; \
            if (y < 0) y = 0; \
-           m_Osd->DrawBitmap(x, OSDSTATUSWIN_Y(offset + y), *bm, femonTheme[femonConfig.theme].clrTitleText, femonTheme[femonConfig.theme].clrTitleBackground); \
+           m_Osd->DrawBitmap(x, OSDSTATUSWIN_Y(offset) + y, *bm, femonTheme[femonConfig.theme].clrTitleText, femonTheme[femonConfig.theme].clrTitleBackground); \
            }
 
 #define OSDDRAWSTATUSFRONTEND(column, bitmap, status) \
-        m_Osd->DrawBitmap(OSDSTATUSWIN_XSYMBOL(column, x), OSDSTATUSWIN_Y(offset + y), bitmap, (m_FrontendStatus & status) ? femonTheme[femonConfig.theme].clrActiveText : femonTheme[femonConfig.theme].clrRed, femonTheme[femonConfig.theme].clrBackground)
+        m_Osd->DrawBitmap(OSDSTATUSWIN_XSYMBOL(column, x), OSDSTATUSWIN_Y(offset) + y, bitmap, (m_FrontendStatus & status) ? femonTheme[femonConfig.theme].clrActiveText : femonTheme[femonConfig.theme].clrRed, femonTheme[femonConfig.theme].clrBackground)
 
 #define OSDDRAWSTATUSVALUES(label1, label2, label3, label4, label5, label6, label7) \
         m_Osd->DrawText(OSDSTATUSWIN_X(1), OSDSTATUSWIN_Y(offset), label1, femonTheme[femonConfig.theme].clrInactiveText, femonTheme[femonConfig.theme].clrBackground, m_Font); \
@@ -54,28 +54,31 @@
 #define OSDDRAWSTATUSBAR(value) \
         if (value > 0) { \
            value = OSDBARWIDTH(value); \
-           m_Osd->DrawRectangle(0, OSDSTATUSWIN_Y(offset + 3), min(OSDBARWIDTH(femonConfig.redlimit), value), OSDSTATUSWIN_Y(offset + OSDROWHEIGHT - 3), femonTheme[femonConfig.theme].clrRed); \
+           m_Osd->DrawRectangle(0, OSDSTATUSWIN_Y(offset) + 3, min(OSDBARWIDTH(femonConfig.redlimit), value), OSDSTATUSWIN_Y(offset) + OSDROWHEIGHT - 3, femonTheme[femonConfig.theme].clrRed); \
            if (value > OSDBARWIDTH(femonConfig.redlimit)) \
-              m_Osd->DrawRectangle(OSDBARWIDTH(femonConfig.redlimit), OSDSTATUSWIN_Y(offset + 3), min((OSDWIDTH * femonConfig.greenlimit / 100), value), OSDSTATUSWIN_Y(offset + OSDROWHEIGHT - 3), femonTheme[femonConfig.theme].clrYellow); \
+              m_Osd->DrawRectangle(OSDBARWIDTH(femonConfig.redlimit), OSDSTATUSWIN_Y(offset) + 3, min((OSDWIDTH * femonConfig.greenlimit / 100), value), OSDSTATUSWIN_Y(offset) + OSDROWHEIGHT - 3, femonTheme[femonConfig.theme].clrYellow); \
            if (value > OSDBARWIDTH(femonConfig.greenlimit)) \
-              m_Osd->DrawRectangle(OSDBARWIDTH(femonConfig.greenlimit), OSDSTATUSWIN_Y(offset + 3), value, OSDSTATUSWIN_Y(offset + OSDROWHEIGHT - 3), femonTheme[femonConfig.theme].clrGreen); \
+              m_Osd->DrawRectangle(OSDBARWIDTH(femonConfig.greenlimit), OSDSTATUSWIN_Y(offset) + 3, value, OSDSTATUSWIN_Y(offset) + OSDROWHEIGHT - 3, femonTheme[femonConfig.theme].clrGreen); \
            }
 
 #define OSDDRAWSTATUSTITLEBAR(title) \
-        m_Osd->DrawRectangle(0, OSDSTATUSWIN_Y(0), OSDWIDTH, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT), femonTheme[femonConfig.theme].clrBackground); \
-        m_Osd->DrawRectangle(0, OSDSTATUSWIN_Y(offset), OSDWIDTH, OSDSTATUSWIN_Y(offset+OSDROWHEIGHT-1), femonTheme[femonConfig.theme].clrTitleBackground); \
+        m_Osd->DrawRectangle(0, OSDSTATUSWIN_Y(offset), OSDWIDTH, OSDSTATUSWIN_Y(offset) + OSDROWHEIGHT - 1, femonTheme[femonConfig.theme].clrTitleBackground); \
         m_Osd->DrawText(OSDSTATUSWIN_X(1), OSDSTATUSWIN_Y(offset), title, femonTheme[femonConfig.theme].clrTitleText, femonTheme[femonConfig.theme].clrTitleBackground, m_Font); \
-        if (IS_OSDCORNERING) { \
-           m_Osd->DrawEllipse(0, OSDSTATUSWIN_Y(0), OSDCORNERING, OSDSTATUSWIN_Y(OSDCORNERING), clrTransparent, -2); \
-           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDSTATUSWIN_Y(0), OSDWIDTH, OSDSTATUSWIN_Y(OSDCORNERING), clrTransparent, -1); \
-           }
+        if (IS_OSDROUNDING) { \
+           m_Osd->DrawEllipse(0, OSDSTATUSWIN_Y(0), OSDROUNDING, OSDSTATUSWIN_Y(OSDROUNDING), clrTransparent, -2); \
+           m_Osd->DrawEllipse(OSDWIDTH - OSDROUNDING, OSDSTATUSWIN_Y(0), OSDWIDTH, OSDSTATUSWIN_Y(OSDROUNDING), clrTransparent, -1); \
+           } \
+        m_Osd->DrawRectangle(0, OSDSTATUSWIN_Y(offset) + OSDROWHEIGHT, OSDWIDTH, OSDSTATUSWIN_Y(offset) + OSDSTATUSHEIGHT - 1, femonTheme[femonConfig.theme].clrBackground)
 
 #define OSDDRAWSTATUSBOTTOMBAR() \
-        if (IS_OSDCORNERING) { \
-           m_Osd->DrawEllipse(0, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT-OSDCORNERING), OSDCORNERING, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT), clrTransparent, -3); \
-           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDSTATUSWIN_Y(OSDSTATUSHEIGHT-OSDCORNERING), OSDWIDTH, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT), clrTransparent, -4); \
+        if (IS_OSDROUNDING) { \
+           m_Osd->DrawEllipse(0, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT) - OSDROUNDING, OSDROUNDING, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT), clrTransparent, -3); \
+           m_Osd->DrawEllipse(OSDWIDTH - OSDROUNDING, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT) - OSDROUNDING, OSDWIDTH, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT), clrTransparent, -4); \
            }
 
+#define OSDCLEARSTATUS() \
+        m_Osd->DrawRectangle(0, OSDSTATUSWIN_Y(0), OSDWIDTH, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT) - 1, clrTransparent)
+
 #define OSDDRAWINFOLEFT(label, value) \
         m_Osd->DrawText(OSDINFOWIN_X(1), OSDINFOWIN_Y(offset), label, femonTheme[femonConfig.theme].clrInactiveText, femonTheme[femonConfig.theme].clrBackground, m_Font); \
         m_Osd->DrawText(OSDINFOWIN_X(2), OSDINFOWIN_Y(offset), value, femonTheme[femonConfig.theme].clrActiveText, femonTheme[femonConfig.theme].clrBackground, m_Font)
@@ -96,29 +99,45 @@
         m_Osd->DrawText(OSDINFOWIN_X(1), OSDINFOWIN_Y(offset), label, femonTheme[femonConfig.theme].clrActiveText, femonTheme[femonConfig.theme].clrBackground, m_Font)
 
 #define OSDDRAWINFOTITLEBAR(title) \
-        m_Osd->DrawRectangle(0, OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), femonTheme[femonConfig.theme].clrBackground); \
-        m_Osd->DrawRectangle(0, OSDINFOWIN_Y(offset), OSDWIDTH, OSDINFOWIN_Y(offset + OSDROWHEIGHT - 1), femonTheme[femonConfig.theme].clrTitleBackground); \
+        m_Osd->DrawRectangle(0, OSDINFOWIN_Y(offset), OSDWIDTH, OSDINFOWIN_Y(offset) + OSDROWHEIGHT - 1, femonTheme[femonConfig.theme].clrTitleBackground); \
         m_Osd->DrawText(OSDINFOWIN_X(1), OSDINFOWIN_Y(offset), title, femonTheme[femonConfig.theme].clrTitleText, femonTheme[femonConfig.theme].clrTitleBackground, m_Font); \
-        if (IS_OSDCORNERING) { \
-           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(0), OSDCORNERING, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -2); \
-           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -1); \
-           }
+        if (IS_OSDROUNDING) { \
+           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(0), OSDROUNDING, OSDINFOWIN_Y(OSDROUNDING), clrTransparent, -2); \
+           m_Osd->DrawEllipse(OSDWIDTH - OSDROUNDING, OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDROUNDING), clrTransparent, -1); \
+           } \
+        m_Osd->DrawRectangle(0, OSDINFOWIN_Y(offset) + OSDROWHEIGHT, OSDWIDTH, OSDINFOWIN_Y(offset) + OSDINFOHEIGHT - 1, femonTheme[femonConfig.theme].clrBackground)
 
 #define OSDDRAWINFOBOTTOMBAR() \
-        if (IS_OSDCORNERING) { \
-           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDCORNERING, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -3); \
-           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -4); \
+        if (IS_OSDROUNDING) { \
+           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(OSDINFOHEIGHT) - OSDROUNDING, OSDROUNDING, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -3); \
+           m_Osd->DrawEllipse((OSDWIDTH - OSDROUNDING), OSDINFOWIN_Y(OSDINFOHEIGHT) - OSDROUNDING, OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -4); \
            }
 
 #define OSDCLEARINFO() \
-        m_Osd->DrawRectangle(0, OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent)
+        m_Osd->DrawRectangle(0, OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT) - 1, clrTransparent)
+
+#ifndef MINFONTSIZE
+#define MINFONTSIZE 10
+#endif
+
+#ifndef MAXFONTSIZE
+#define MAXFONTSIZE 64
+#endif
+
+class cFemonDummyFont : public cFont {
+public:
+  virtual int Width(uint c) const { return 10; }
+  virtual int Width(const char *s) const { return 50; }
+  virtual int Height(void) const { return 20; }
+  virtual void DrawText(cBitmap *Bitmap, int x, int y, const char *s, tColor ColorFg, tColor ColorBg, int Width) const {}
+};
 
 cFemonOsd *cFemonOsd::pInstance = NULL;
 
 cFemonOsd *cFemonOsd::Instance(bool create)
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
-  if (pInstance == NULL && create)
+  if ((pInstance == NULL) && create)
   {
      pInstance = new cFemonOsd();
   }
@@ -126,34 +145,34 @@ cFemonOsd *cFemonOsd::Instance(bool create)
 }
 
 cFemonOsd::cFemonOsd()
-:cOsdObject(true), cThread("femon osd")
+: cOsdObject(true), cThread("femon osd"),
+  m_Osd(NULL),
+  m_Receiver(NULL),
+  m_Frontend(-1),
+  m_SvdrpFrontend(-1),
+  m_SvdrpVideoBitrate(-1),
+  m_SvdrpAudioBitrate(-1),
+  m_SvdrpPlugin(NULL),
+  m_Number(0),
+  m_OldNumber(0),
+  m_SNR(0),
+  m_Signal(0),
+  m_BER(0),
+  m_UNC(0),
+  m_DisplayMode(femonConfig.displaymode),
+  m_InputTime(0),
+  m_Sleep(),
+  m_Mutex()
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
-  m_Osd = NULL;
-  m_Receiver = NULL;
-  m_Frontend = -1;
-  m_SvdrpVideoBitrate = -1.0;
-  m_SvdrpAudioBitrate = -1.0;
-  m_SvdrpFrontend = -1;
   m_SvdrpConnection.handle = -1;
-  m_SvdrpPlugin = NULL;
-  m_Number = 0;
-  m_OldNumber = 0;
-  m_Signal = 0;
-  m_SNR = 0;
-  m_BER = 0;
-  m_UNC = 0;
-  m_DisplayMode = femonConfig.displaymode;
-  m_InputTime.Set(0);
-  m_Mutex = new cMutex();
-  if (Setup.UseSmallFont == 0) {
-     // Dirty hack to force the small fonts...
-     Setup.UseSmallFont = 1;
-     m_Font = cFont::GetFont(fontSml);
-     Setup.UseSmallFont = 0;
+  m_Font = cFont::CreateFont(Setup.FontSml, min(max(Setup.FontSmlSize, MINFONTSIZE), MAXFONTSIZE));
+  if (!m_Font || !m_Font->Height()) {
+     m_Font = new cFemonDummyFont;
+     esyslog("ERROR: cFemonOsd::cFemonOsd() cannot create required font.");
      }
-  else
-     m_Font = cFont::GetFont(fontSml);
+  if (OSDHEIGHT < (OSDINFOHEIGHT + OSDROWHEIGHT + OSDSTATUSHEIGHT))
+     OSDHEIGHT = (OSDINFOHEIGHT + OSDROWHEIGHT + OSDSTATUSHEIGHT);
 }
 
 cFemonOsd::~cFemonOsd(void)
@@ -167,21 +186,29 @@ cFemonOsd::~cFemonOsd(void)
      if (m_SvdrpPlugin)
         m_SvdrpPlugin->Service("SvdrpConnection-v1.0", &m_SvdrpConnection);
      }
-  if (m_Receiver)
-     delete m_Receiver;
+  if (m_Receiver) {
+     m_Receiver->Deactivate();
+     DELETENULL(m_Receiver);
+     }
   if (m_Osd)
-     delete m_Osd;
+     DELETENULL(m_Osd);
+  if (m_Font)
+     DELETENULL(m_Font);
+  if (m_Frontend >= 0) {
+     close(m_Frontend);
+     m_Frontend = -1;
+     }
   pInstance = NULL;
 }
 
 void cFemonOsd::DrawStatusWindow(void)
 {
-  cMutexLock lock(m_Mutex);
+  cMutexLock lock(&m_Mutex);
   cBitmap *bm = NULL;
   int snr = m_SNR / 655;
   int signal = m_Signal / 655;
   int offset = 0;
-  int x = OSDWIDTH - OSDCORNERING;
+  int x = OSDWIDTH - OSDROUNDING;
   int y = 0;
   eTrackType track = cDevice::PrimaryDevice()->GetCurrentAudioTrack();
   cChannel *channel = Channels.GetByNumber(cDevice::CurrentChannel());
@@ -262,7 +289,7 @@ void cFemonOsd::DrawStatusWindow(void)
      OSDDRAWSTATUSBAR(snr);
      offset += OSDROWHEIGHT;
      OSDDRAWSTATUSVALUES("STR:", *cString::sprintf("%04x", m_Signal), *cString::sprintf("(%2d%%)", m_Signal / 655), "BER:", *cString::sprintf("%08x", m_BER),
-                         *cString::sprintf("%s:", tr("Video")),  *getBitrateMbits(m_Receiver ? m_Receiver->VideoBitrate() : (m_SvdrpFrontend >= 0 ? m_SvdrpVideoBitrate : -1.0)));
+                         *cString::sprintf("%s:", tr("Video")), *getBitrateMbits(m_Receiver ? m_Receiver->VideoBitrate() : (m_SvdrpFrontend >= 0 ? m_SvdrpVideoBitrate : -1.0)));
      offset += OSDROWHEIGHT;
      OSDDRAWSTATUSVALUES("SNR:", *cString::sprintf("%04x", m_SNR), *cString::sprintf("(%2d%%)", m_SNR / 655), "UNC:", *cString::sprintf("%08x", m_UNC),
                          *cString::sprintf("%s:", (m_Receiver && m_Receiver->AC3Valid() && IS_DOLBY_TRACK(track)) ? tr("AC-3") : tr("Audio")),
@@ -282,7 +309,7 @@ void cFemonOsd::DrawStatusWindow(void)
 
 void cFemonOsd::DrawInfoWindow(void)
 {
-  cMutexLock lock(m_Mutex);
+  cMutexLock lock(&m_Mutex);
   int offset = 0;
   cChannel *channel = Channels.GetByNumber(cDevice::CurrentChannel());
   eTrackType track = cDevice::PrimaryDevice()->GetCurrentAudioTrack();
@@ -307,11 +334,11 @@ void cFemonOsd::DrawInfoWindow(void)
             OSDDRAWINFOLEFT(    tr("Tid"),  *cString::sprintf("%d", channel->Tid()));
             OSDDRAWINFORIGHT(   tr("Rid"),  *cString::sprintf("%d", channel->Rid()));
             offset += OSDROWHEIGHT;
-            OSDDRAWINFOLEFT( trVDR("CA"),   *getCAids(channel, femonConfig.showcasystem));
+            OSDDRAWINFOLEFT( trVDR("CA"),   *getCAids(channel));
             offset += OSDROWHEIGHT;
-            switch (m_FrontendInfo.type) {
-              case FE_QPSK:
-                   OSDDRAWINFOLINE(*cString::sprintf("%s #%d - %s", tr("Satellite Card"), (m_SvdrpFrontend >= 0) ? m_SvdrpFrontend : cDevice::ActualDevice()->CardIndex(), m_FrontendInfo.name));
+            switch (channel->Source() & cSource::st_Mask) {
+              case cSource::stSat:
+                   OSDDRAWINFOLINE(*cString::sprintf("DVB-S #%d - %s", (m_SvdrpFrontend >= 0) ? m_SvdrpFrontend : cDevice::ActualDevice()->CardIndex(), m_FrontendInfo.name));
                    offset += OSDROWHEIGHT;
                    OSDDRAWINFOLEFT( trVDR("Frequency"),    *getFrequencyMHz(channel->Frequency()));
                    OSDDRAWINFORIGHT(trVDR("Source"),       *cSource::ToString(channel->Source()));
@@ -321,13 +348,10 @@ void cFemonOsd::DrawInfoWindow(void)
                    offset += OSDROWHEIGHT;
                    OSDDRAWINFOLEFT( trVDR("Inversion"),    *getInversion(channel->Inversion()));
                    OSDDRAWINFORIGHT(trVDR("CoderateH"),    *getCoderate(channel->CoderateH()));
-                   //offset += OSDROWHEIGHT;
-                   //OSDDRAWINFOLEFT( trVDR("System"),     *getSystem(channel->System()));
-                   //OSDDRAWINFORIGHT(trVDR("RollOff"),    *getRollOff(channel->RollOff()));
                    break;
 
-             case FE_QAM:
-                   OSDDRAWINFOLINE(*cString::sprintf("%s #%d - %s", tr("Cable Card"), (m_SvdrpFrontend >= 0) ? m_SvdrpFrontend : cDevice::ActualDevice()->CardIndex(), m_FrontendInfo.name));
+              case cSource::stCable:
+                   OSDDRAWINFOLINE(*cString::sprintf("DVB-C #%d - %s", (m_SvdrpFrontend >= 0) ? m_SvdrpFrontend : cDevice::ActualDevice()->CardIndex(), m_FrontendInfo.name));
                    offset += OSDROWHEIGHT;
                    OSDDRAWINFOLEFT( trVDR("Frequency"),    *getFrequencyMHz(channel->Frequency()));
                    OSDDRAWINFORIGHT(trVDR("Source"),       *cSource::ToString(channel->Source()));
@@ -339,8 +363,8 @@ void cFemonOsd::DrawInfoWindow(void)
                    OSDDRAWINFORIGHT(trVDR("CoderateH"),    *getCoderate(channel->CoderateH()));
                    break;
 
-              case FE_OFDM:
-                   OSDDRAWINFOLINE(*cString::sprintf("%s #%d - %s", tr("Terrestrial Card"), (m_SvdrpFrontend >= 0) ? m_SvdrpFrontend : cDevice::ActualDevice()->CardIndex(), m_FrontendInfo.name));
+              case cSource::stTerr:
+                   OSDDRAWINFOLINE(*cString::sprintf("DVB-T #%d - %s", (m_SvdrpFrontend >= 0) ? m_SvdrpFrontend : cDevice::ActualDevice()->CardIndex(), m_FrontendInfo.name));
                    offset += OSDROWHEIGHT;
                    OSDDRAWINFOLEFT( trVDR("Frequency"),    *getFrequencyMHz(channel->Frequency()));
                    OSDDRAWINFORIGHT(trVDR("Transmission"), *getTransmission(channel->Transmission()));
@@ -353,9 +377,6 @@ void cFemonOsd::DrawInfoWindow(void)
                    offset += OSDROWHEIGHT;
                    OSDDRAWINFOLEFT( trVDR("Hierarchy"),    *getHierarchy(channel->Hierarchy()));
                    OSDDRAWINFORIGHT(trVDR("Guard"),        *getGuard(channel->Guard()));
-                   //offset += OSDROWHEIGHT;
-                   //OSDDRAWINFOLEFT( trVDR("Alpha"),      *getAlpha(channel->Alpha()));
-                   //OSDDRAWINFORIGHT(trVDR("Priority"),   *getPriority(channel->Priority()));
                    break;
 
               default:
@@ -367,7 +388,7 @@ void cFemonOsd::DrawInfoWindow(void)
        case eFemonModeStream:
             OSDDRAWINFOTITLEBAR(tr("Stream Information"));
             offset += OSDROWHEIGHT;
-            OSDDRAWINFOACTIVE(  tr("Video Stream"),       *cString::sprintf("#%d", channel->Vpid()));
+            OSDDRAWINFOACTIVE(  tr("Video Stream"),       *getVideoStream(channel->Vpid()));
             offset += OSDROWHEIGHT;
             OSDDRAWINFOINACTIVE(tr("Codec"),              *getVideoCodec(m_Receiver ? m_Receiver->VideoCodec() : VIDEO_CODEC_INVALID));
             offset += OSDROWHEIGHT;
@@ -381,7 +402,7 @@ void cFemonOsd::DrawInfoWindow(void)
             offset += OSDROWHEIGHT;
             OSDDRAWINFOINACTIVE(tr("Resolution"),         *getResolution(m_Receiver ? m_Receiver->VideoHorizontalSize() : 0, m_Receiver ? m_Receiver->VideoVerticalSize() : 0, m_Receiver ? m_Receiver->VideoScan() : VIDEO_SCAN_INVALID));
             offset += OSDROWHEIGHT;
-            OSDDRAWINFOACTIVE(  tr("Audio Stream"),       *cString::sprintf("#%d (%s)", IS_AUDIO_TRACK(track) ? channel->Apid(int(track - ttAudioFirst)) : channel->Apid(0), IS_AUDIO_TRACK(track) ? channel->Alang(int(track - ttAudioFirst)) : channel->Alang(0)));
+            OSDDRAWINFOACTIVE(  tr("Audio Stream"),       *getAudioStream(track, channel));
             offset += OSDROWHEIGHT;
             OSDDRAWINFOINACTIVE(tr("Codec"),              *getAudioCodec(m_Receiver ? m_Receiver->AudioCodec() : AUDIO_CODEC_INVALID));
             offset += OSDROWHEIGHT;
@@ -397,7 +418,7 @@ void cFemonOsd::DrawInfoWindow(void)
             OSDDRAWINFOTITLEBAR(tr("Stream Information"));
             if (m_Receiver && m_Receiver->AC3Valid() && IS_DOLBY_TRACK(track)) {
                offset += OSDROWHEIGHT;
-               OSDDRAWINFOINACTIVE(tr("AC-3 Stream"),            *cString::sprintf("#%d %s", channel->Dpid(int(track - ttDolbyFirst)), channel->Dlang(int(track - ttDolbyFirst))));
+               OSDDRAWINFOACTIVE(  tr("AC-3 Stream"),            *getAC3Stream(track, channel));
                offset += OSDROWHEIGHT;
                OSDDRAWINFOINACTIVE(tr("Bitrate"),                *getAudioBitrate(m_Receiver->AC3Bitrate(), m_Receiver->AC3StreamBitrate()));
                offset += OSDROWHEIGHT;
@@ -453,28 +474,28 @@ void cFemonOsd::Action(void)
        m_SvdrpPlugin->Service("SvdrpCommand-v1.0", &cmd);
        if (cmd.responseCode == 900) {
           for (cLine *line = cmd.reply.First(); line; line = cmd.reply.Next(line)) {
-             const char *s = line->Text();
-	      if (strncasecmp(s, "CARD:", 5) == 0)
-                m_SvdrpFrontend = strtol(s + 5, NULL, 10);
-             else if (strncasecmp(s, "TYPE:", 5) == 0)
-                m_FrontendInfo.type = (fe_type_t) strtol(s + 5, NULL, 10);
-             else if (strncasecmp(s, "NAME:", 5) == 0)
-                strn0cpy(m_FrontendInfo.name, s + 5, sizeof(m_FrontendInfo.name));
-             else if (strncasecmp(s, "STAT:", 5) == 0)
-                m_FrontendStatus = (fe_status_t) strtol(s + 5, NULL, 16);
-             else if (strncasecmp(s, "SGNL:", 5) == 0)
-                m_Signal = strtol(s + 5, NULL, 16);
-             else if (strncasecmp(s, "SNRA:", 5) == 0)
-                m_SNR = strtol(s + 5, NULL, 16);
-             else if (strncasecmp(s, "BERA:", 5) == 0)
-                m_BER = strtol(s + 5, NULL, 16);
-             else if (strncasecmp(s, "UNCB:", 5) == 0)
-                m_UNC = strtol(s + 5, NULL, 16);
-             else if (strncasecmp(s, "VIBR:", 5) == 0)
-                m_SvdrpVideoBitrate = strtol(s + 5, NULL, 10);
-             else if (strncasecmp(s, "AUBR:", 5) == 0)
-                m_SvdrpAudioBitrate = strtol(s + 5, NULL, 10);
-             }
+              const char *s = line->Text();
+	      if (!strncasecmp(s, "CARD:", 5))
+                 m_SvdrpFrontend = (int)strtol(s + 5, NULL, 10);
+              else if (!strncasecmp(s, "TYPE:", 5))
+                 m_FrontendInfo.type = (fe_type_t)strtol(s + 5, NULL, 10);
+              else if (!strncasecmp(s, "NAME:", 5))
+                 strn0cpy(m_FrontendInfo.name, s + 5, sizeof(m_FrontendInfo.name));
+              else if (!strncasecmp(s, "STAT:", 5))
+                 m_FrontendStatus = (fe_status_t)strtol(s + 5, NULL, 16);
+              else if (!strncasecmp(s, "SGNL:", 5))
+                 m_Signal = (uint16_t)strtol(s + 5, NULL, 16);
+              else if (!strncasecmp(s, "SNRA:", 5))
+                 m_SNR = (uint16_t)strtol(s + 5, NULL, 16);
+              else if (!strncasecmp(s, "BERA:", 5))
+                 m_BER = (uint32_t)strtol(s + 5, NULL, 16);
+              else if (!strncasecmp(s, "UNCB:", 5))
+                 m_UNC = (uint32_t)strtol(s + 5, NULL, 16);
+              else if (!strncasecmp(s, "VIBR:", 5))
+                 m_SvdrpVideoBitrate = (double)strtol(s + 5, NULL, 10);
+              else if (!strncasecmp(s, "AUBR:", 5))
+                 m_SvdrpAudioBitrate = (double)strtol(s + 5, NULL, 10);
+              }
           }
        DrawInfoWindow();
        DrawStatusWindow();
@@ -510,21 +531,23 @@ void cFemonOsd::Show(void)
 
   m_Osd = cOsdProvider::NewOsd(((cOsd::OsdWidth() - OSDWIDTH) / 2) + cOsd::OsdLeft() + femonConfig.osdoffset, ((cOsd::OsdHeight() - OSDHEIGHT) / 2) + cOsd::OsdTop());
   if (m_Osd) {
-     // try to use single 8bpp area
-     tArea Areas1[] = { { 0, 0, OSDWIDTH, OSDHEIGHT, 8 } };
-     if (femonConfig.usesinglearea && m_Osd->CanHandleAreas(Areas1, sizeof(Areas1) / sizeof(tArea)) == oeOk) {
+     tArea Areas1[] = { { 0, 0, OSDWIDTH - 1, OSDHEIGHT - 1, 8 } };
+     if (Setup.AntiAlias && m_Osd->CanHandleAreas(Areas1, sizeof(Areas1) / sizeof(tArea)) == oeOk) {
         m_Osd->SetAreas(Areas1, sizeof(Areas1) / sizeof(tArea));
         }
      else {
-        tArea Areas2[] = { { 0, OSDSTATUSWIN_Y(0),          (OSDWIDTH - 1), OSDSTATUSWIN_Y(OSDSTATUSHEIGHT - 1), femonTheme[femonConfig.theme].bpp },
-                           { 0, OSDINFOWIN_Y(0),            (OSDWIDTH - 1), OSDINFOWIN_Y(OSDROWHEIGHT - 1),      femonTheme[femonConfig.theme].bpp },
-                           { 0, OSDINFOWIN_Y(OSDROWHEIGHT), (OSDWIDTH - 1), OSDINFOWIN_Y(OSDINFOHEIGHT - 1),     2 } };
+        tArea Areas2[] = { { 0, OSDSTATUSWIN_Y(0),          OSDWIDTH - 1, OSDSTATUSWIN_Y(0) + OSDSTATUSHEIGHT - 1, femonTheme[femonConfig.theme].bpp },
+                           { 0, OSDINFOWIN_Y(0),            OSDWIDTH - 1, OSDINFOWIN_Y(0)   + OSDROWHEIGHT    - 1, femonTheme[femonConfig.theme].bpp },
+                           { 0, OSDINFOWIN_Y(OSDROWHEIGHT), OSDWIDTH - 1, OSDINFOWIN_Y(0)   + OSDINFOHEIGHT   - 1, 2                                 } };
         m_Osd->SetAreas(Areas2, sizeof(Areas2) / sizeof(tArea));
         }
-     m_Osd->DrawRectangle(0, OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent);
+     OSDCLEARSTATUS();
+     OSDCLEARINFO();
      m_Osd->Flush();
-     if (m_Receiver)
-        delete m_Receiver;
+     if (m_Receiver) {
+        m_Receiver->Deactivate();
+        DELETENULL(m_Receiver);
+        }
      if (femonConfig.analyzestream) {
         cChannel *channel = Channels.GetByNumber(cDevice::CurrentChannel());
         if (channel) {
@@ -566,8 +589,10 @@ void cFemonOsd::ChannelSwitch(const cDevice * device, int channelNumber)
      return;
      }
 
-  if (m_Receiver)
-     delete m_Receiver;
+  if (m_Receiver) {
+     m_Receiver->Deactivate();
+     DELETENULL(m_Receiver);
+     }
   if (femonConfig.analyzestream) {
      cChannel *channel = Channels.GetByNumber(cDevice::CurrentChannel());
      if (channel) {
@@ -585,8 +610,10 @@ void cFemonOsd::SetAudioTrack(int Index, const char * const *Tracks)
   int apid[2] = {0, 0};
   int dpid[2] = {0, 0};
   eTrackType track = cDevice::PrimaryDevice()->GetCurrentAudioTrack();
-  if (m_Receiver)
-     delete m_Receiver;
+  if (m_Receiver) {
+     m_Receiver->Deactivate();
+     DELETENULL(m_Receiver);
+     }
   if (femonConfig.analyzestream) {
      cChannel *channel = Channels.GetByNumber(cDevice::CurrentChannel());
      if (channel) {
@@ -638,7 +665,7 @@ bool cFemonOsd::SvdrpConnect(void)
       m_SvdrpPlugin = cPluginManager::GetPlugin(SVDRPPLUGIN);
       if (m_SvdrpPlugin) {
          m_SvdrpConnection.serverIp = femonConfig.svdrpip;
-         m_SvdrpConnection.serverPort = femonConfig.svdrpport;
+         m_SvdrpConnection.serverPort = (unsigned short)femonConfig.svdrpport;
          m_SvdrpConnection.shared = true;
          m_SvdrpPlugin->Service("SvdrpConnection-v1.0", &m_SvdrpConnection);
          if (m_SvdrpConnection.handle >= 0) {
@@ -833,6 +860,6 @@ eOSState cFemonOsd::ProcessKey(eKeys Key)
             break;
        }
      state = osContinue;
-  }
+     }
   return state;
 }
