@@ -25,27 +25,29 @@
 class cFemonOsd : public cOsdObject, public cThread, public cStatus {
 private:
   static cFemonOsd *pInstance;
-  cOsd *m_Osd;
-  cFemonReceiver *m_Receiver;
-  int m_Frontend;
-  int m_SvdrpFrontend;
-  double m_SvdrpVideoBitrate;
-  double m_SvdrpAudioBitrate;
+
+  cOsd             *m_Osd;
+  cFemonReceiver   *m_Receiver;
+  int               m_Frontend;
+  int               m_SvdrpFrontend;
+  double            m_SvdrpVideoBitrate;
+  double            m_SvdrpAudioBitrate;
   SvdrpConnection_v1_0 m_SvdrpConnection;
-  cPlugin *m_SvdrpPlugin;
-  struct dvb_frontend_info m_FrontendInfo;
-  int m_Number;
-  int m_OldNumber;
-  uint16_t m_SNR;
-  uint16_t m_Signal;
-  uint32_t m_BER;
-  uint32_t m_UNC;
-  fe_status_t m_FrontendStatus;
-  int m_DisplayMode;
-  const cFont *m_Font;
-  cTimeMs m_InputTime;
-  cCondWait m_Sleep;
-  cMutex* m_Mutex;
+  cPlugin          *m_SvdrpPlugin;
+  dvb_frontend_info m_FrontendInfo;
+  int               m_Number;
+  int               m_OldNumber;
+  uint16_t          m_SNR;
+  uint16_t          m_Signal;
+  uint32_t          m_BER;
+  uint32_t          m_UNC;
+  fe_status_t       m_FrontendStatus;
+  int               m_DisplayMode;
+  cFont            *m_Font;
+  cTimeMs           m_InputTime;
+  cCondWait         m_Sleep;
+  cMutex            m_Mutex;
+
   void DrawStatusWindow(void);
   void DrawInfoWindow(void);
   bool SvdrpConnect(void);
@@ -66,10 +68,10 @@ public:
   virtual void Show(void);
   virtual eOSState ProcessKey(eKeys Key);
 
-  bool DeviceSwitch(int direction);
-  double GetVideoBitrate(void);
-  double GetAudioBitrate(void);
-  double GetDolbyBitrate(void);
+  bool    DeviceSwitch(int direction);
+  double  GetVideoBitrate(void);
+  double  GetAudioBitrate(void);
+  double  GetDolbyBitrate(void);
 };
 
 #endif //__FEMONOSD_H
